<?php

namespace Hrm\Vacancy\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Vacancy\Models\Vacancy;

class VacancyPolicy
{

    /**
     * Determine if the given user can view the vacancy.
     *
     * @param UserPolicy $user
     * @param Vacancy $vacancy
     *
     * @return bool
     */
    public function view(UserPolicy $user, Vacancy $vacancy)
    {
        if ($user->canDo('vacancy.vacancy.view') && $user->isAdmin()) {
            return true;
        }

        return $vacancy->user_id == user_id() && $vacancy->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vacancy.
     *
     * @param UserPolicy $user
     * @param Vacancy $vacancy
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('vacancy.vacancy.create');
    }

    /**
     * Determine if the given user can update the given vacancy.
     *
     * @param UserPolicy $user
     * @param Vacancy $vacancy
     *
     * @return bool
     */
    public function update(UserPolicy $user, Vacancy $vacancy)
    {
        if ($user->canDo('vacancy.vacancy.edit') && $user->isAdmin()) {
            return true;
        }

        return $vacancy->user_id == user_id() && $vacancy->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vacancy.
     *
     * @param UserPolicy $user
     * @param Vacancy $vacancy
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Vacancy $vacancy)
    {
        return $vacancy->user_id == user_id() && $vacancy->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vacancy.
     *
     * @param UserPolicy $user
     * @param Vacancy $vacancy
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Vacancy $vacancy)
    {
        if ($user->canDo('vacancy.vacancy.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vacancy.
     *
     * @param UserPolicy $user
     * @param Vacancy $vacancy
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Vacancy $vacancy)
    {
        if ($user->canDo('vacancy.vacancy.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
