<?php

namespace Hrm\Vacancy\Providers;

use Illuminate\Support\ServiceProvider;

class VacancyServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'vacancy');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'vacancy');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerVacancy();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerVacancy()
    {
        $this->app->bind('vacancy', function($app) {
            return new Vacancy($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Vacancy', 'Lavalite\Vacancy\Facades\Vacancy');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('hrm.vacancy', function ($app) {
            return $this->app->make('Hrm\Vacancy\Vacancy');
        });

                // Bind Vacancy to repository
        $this->app->bind(
            'Hrm\Vacancy\Interfaces\VacancyRepositoryInterface',
            \Hrm\Vacancy\Repositories\Eloquent\VacancyRepository::class
        );

        $this->app->register(\Hrm\Vacancy\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hrm\Vacancy\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and vacancy's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/vacancy.php', 'vacancy'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeVacancy::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hrm.vacancy'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hrm/vacancy.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/vacancy')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/vacancy')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
